/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/material.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/atoms/atoms.dart';

/// The possible card types
enum ZwapCardType { levelZero, levelOne, levelTwo, levelThree }

/// Custom component to render the card
class ZwapCard extends StatelessWidget {
  /// The card type
  final ZwapCardType zwapCardType;

  /// The child component of this card
  final Widget child;

  /// The card width
  final double? cardWidth;

  /// The card height
  final double? cardHeight;

  /// The background color for this card
  final Color? backgroundColor;

  final Color? borderColor;

  ZwapCard(
      {Key? key,
      required this.zwapCardType,
      required this.child,
      this.backgroundColor,
      this.cardHeight,
      this.borderColor,
      this.cardWidth})
      : super(key: key);

  /// It retrieves the box shadow for this card in base of the type
  BoxShadow? _getBoxShadow() {
    switch (this.zwapCardType) {
      case ZwapCardType.levelZero:
        return ZwapShadow.levelZero;
      case ZwapCardType.levelOne:
        return ZwapShadow.levelOne;
      case ZwapCardType.levelTwo:
        return ZwapShadow.levelTwo;
      case ZwapCardType.levelThree:
        return ZwapShadow.levelThree;
    }
  }

  @override
  Widget build(BuildContext context) {
    BoxShadow? boxShadow = this._getBoxShadow();
    return Container(
      height: this.cardHeight,
      width: this.cardWidth,
      padding: EdgeInsets.zero,
      child: new Card(
        elevation: 0,
        color: this.backgroundColor ?? ZwapColors.shades0,
        child: Container(
          child: this.child,
        ),
      ),
      decoration: BoxDecoration(
          border: Border.all(
              color: this.borderColor ?? Colors.transparent, width: 0.7),
          borderRadius:
              BorderRadius.all(Radius.circular(ZwapRadius.popupRadius)),
          boxShadow: boxShadow != null ? [boxShadow] : null
      ),
    );
  }
}
